
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 1
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yynoreturn yy_fatal_error (yyconst char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 35
#define YY_END_OF_BUFFER 36
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[600] =
    {   0,
        0,    0,   36,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   19,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   31,   30,   24,   23,   22,   21,
       20,   33,   32,   26,   25,   29,   28,   27,   15,    0,
       16,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   15,
        0,   16,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   17,   18,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   12,   12,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   12,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   12,   10,    0,    7,    7,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   13,
       14,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    7,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    9,    0,    0,
        0,    0,    0,    7,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   11,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        6,    6,    6,    6,    6,    6,    6,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    5,    0,    5,    0,

        0,    0,    0,    0,    0,    3,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    5,    5,
        5,    0,    0,   11,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    5,
        0,    0,    8,    6,    6,    0,    6,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    3,    0,    0,
        0,    6,    0,    0,    0,    0,    0,    0,    0,    6,
        6,    0,    2,    4,    1,    1,    0,    8,    6,    0,
        0,    0,    1,    0,    0,    1,    2,    4,    0

    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    5,
        5,    1,    6,    7,    8,    1,    9,   10,   11,   10,
       10,   10,   10,   10,   10,   10,   10,   12,    1,    1,
        1,    1,    1,    1,   13,   14,   15,   16,   17,   18,
       19,   20,   21,   22,    1,   23,   24,   25,   26,   27,
        1,   28,   29,   30,   31,   32,   33,    1,   34,    1,
       35,    1,   36,    1,    1,    1,   37,   14,   38,   39,

       40,   18,   41,   42,   21,   22,    1,   23,   43,   44,
       26,   45,    1,   28,   46,   47,   48,   32,   33,    1,
       34,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[49] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1
    } ;

static yyconst flex_uint16_t yy_base[600] =
    {   0,
        0,    0, 1312, 1313,   36,   47,   54,   81,   23,   35,
       42,   56,   73, 1285,   51,   81,   75,   71,   87,   80,
       86,   87, 1286,   91,   97, 1280,  103, 1278,   62,   85,
       88, 1264,   89,   91, 1260,   94, 1258,  128,  131,  141,
      136,  184, 1276,  103,  110, 1289, 1281,  111,  127,  128,
      124, 1269,  128,  130,  124,  128,  133,  156,  158, 1263,
     1254, 1268, 1267, 1266, 1265, 1264, 1263, 1262, 1261, 1260,
     1259, 1258, 1257, 1256, 1255, 1313, 1237, 1236, 1235, 1234,
     1233, 1232, 1231, 1230, 1229, 1228, 1227, 1226, 1225, 1224,
      179,  188,  174,  162,  166,  190,  191, 1244,  192,  191,

      200,  202,  204,  214,  221,  222,  230,  238,  239,  242,
      246,  245,  249,  257,  263,  253,  264,  270,  286,  287,
      297,  303, 1233, 1232, 1313, 1313, 1313, 1313, 1313, 1313,
     1313, 1313, 1313, 1313, 1313, 1313, 1313, 1313,  226,  271,
      274,  287, 1239,  237,  291, 1252,  267,  291,  148, 1233,
      283,  282,  308, 1255,  310, 1255,  329, 1239,  295,  299,
      301,  348,  332,  309,  325,  349,  352,  325,  331,  333,
     1247, 1232,  320,  342,  319,  347,  358, 1224, 1223, 1313,
      370, 1313,  372,  367,  391,  395,  398,  399,  402,  403,
      406,  407,  411,  412,  415,  379,  413, 1249,  421,  446,

      423,  399, 1242,  405,  450,  410,  423,  432,  446,  451,
     1229,  451,  450, 1220, 1225,  466, 1218, 1237,  452,  457,
      441, 1216,  458,  458,  447, 1225, 1224, 1313, 1313,  476,
     1224,  452,  458,  454,  462,  501,  502,  471,  476, 1232,
      490,  506,  510,  423,  512,  522,  507,  527,  523,  498,
     1217,  537,  533, 1216,  499,  513, 1229,  520,  521,  350,
     1210,  513,  509,  545, 1207,  565,  531, 1212,  545, 1225,
      566,  562, 1204,  540, 1194, 1193,  567,  574,  584,  557,
     1221,  576, 1206,  588, 1219,  574,  569,  592,  587,  605,
      590, 1224,  595,  600, 1203, 1196,  590,  578,  591,  606,

      607, 1203,  607,  606,  626,  622,  623,  630,  637,  646,
      647,  657,  653,  658,  663,  667, 1200,  672, 1193,  612,
     1192,  675,  629, 1189, 1188,  682,  692,  679,  616, 1195,
     1188,  661, 1193, 1206,  694,  686, 1313,  689,  705,  715,
      706,  709, 1191,  699,  705, 1204,  698,  704,  696, 1185,
      691,  646,  735, 1193,  703,  704,  702,  718,  732,  749,
      715,  717, 1201,  727,  750,  754, 1186,  761, 1179, 1313,
     1313,  760,  762,  772, 1184, 1177, 1182,  773,  749, 1197,
      768,  770,  788,  782,  777,  789,  793,  799,  803,  800,
      806,  807,  821,  811,  820,  825,  842,  846,  849,  853,

      786, 1194,  826, 1179,  860, 1192,  835,  834,  865,  876,
      860,  877,  880,  883,  884, 1177,  863,  755, 1176, 1177,
      876,  870,  874,  890,  894, 1179,  790,  876,  868,  889,
      904,  907,  875,  879, 1187,  893,  919,  923,  930,  934,
      903, 1172, 1165,  911, 1170, 1156, 1153,  929,  940, 1148,
      935, 1090,  906,  905,  916,  916,  931,  933,  943,  945,
      955,  928, 1091,  948, 1061,  961, 1056,  949,  938,  957,
      966,  980, 1030,  991,  993,  984,  953,  963,  969,  984,
      967,  971,  961,  981,  985,  969,  974, 1001, 1012,  998,
      984,  887,  832,  987,  817,  826, 1024,  997, 1035, 1019,

     1022, 1015, 1036, 1039,  804,  786, 1038,  782, 1040, 1031,
     1039,  741, 1040, 1025, 1039, 1039, 1055, 1050, 1070,  608,
      523,  514, 1060, 1046, 1080, 1065, 1077, 1082, 1092, 1102,
     1112, 1071, 1087, 1313, 1090,  445,  362, 1069,  274, 1079,
     1070, 1081, 1114, 1113, 1126, 1127, 1130,  247, 1125, 1136,
     1137, 1110,  221, 1313, 1313, 1120, 1313, 1129,  195, 1128,
      208, 1135, 1146,  205, 1141, 1151, 1148, 1313, 1153,  127,
       71, 1313, 1134, 1158, 1162, 1164, 1166, 1168, 1170, 1313,
     1313,   63,   60,   50, 1172, 1174, 1152, 1313, 1313, 1176,
     1178, 1180, 1182, 1184, 1186, 1313, 1313, 1313, 1313

    } ;

static yyconst flex_int16_t yy_def[600] =
    {   0,
      599,    1,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,

      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,

      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,

      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,

      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,

      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,    0

    } ;

static yyconst flex_uint16_t yy_nxt[1362] =
    {   0,
        4,    5,    5,    5,    5,    6,    4,    7,    4,    8,
        8,    4,    9,    4,    4,   10,    4,   11,    4,    4,
        4,   12,    4,   13,   14,   15,    4,    4,   16,   17,
        4,    4,   18,    4,   19,    4,    9,    4,   10,    4,
        4,    4,   13,   14,    4,   16,   17,    4,   20,   43,
       21,   45,   22,   44,   23,   24,   38,   38,   46,   25,
       26,  591,   27,   39,   39,   53,   28,   43,   48,   47,
       44,  590,   29,   30,   45,   31,   32,   33,   34,   35,
       36,   46,   40,   37,   40,   50,   49,   59,   53,   41,
       42,   42,   48,   54,   57,   62,  589,   55,   51,   60,

       77,   64,   66,   49,  581,   58,   69,   78,   63,   50,
       59,   56,   71,   61,   65,   67,   57,   54,   74,   70,
       55,  105,   58,   79,  106,   72,   81,   84,   56,   86,
       80,   75,   89,   82,   85,  109,   87,   91,   91,   90,
       92,   92,   40,  105,   40,  101,  101,  106,  114,  110,
      118,  111,  119,   93,  109,  112,   94,  116,   95,  117,
      580,  113,   96,  120,   97,   98,   99,  114,  118,  100,
      111,  119,  121,  122,  116,  191,  117,   93,  145,   94,
      120,  192,  146,   97,   98,   40,  100,   40,  139,  139,
      140,  102,   41,  103,  103,  121,  122,  141,  141,  142,

      143,  145,  147,  149,  144,  146,  151,  152,  153,  154,
      154,  155,  155,  156,  156,  157,  565,  157,  143,  562,
      148,  144,  157,  157,  157,  157,  147,  149,  572,  151,
      152,  157,  569,  157,  158,  180,  180,  148,  160,  162,
      157,  162,  157,  157,  163,  157,  157,  157,  157,  157,
      157,  159,  157,  164,  157,  185,  157,  161,  162,  168,
      162,  160,  167,  163,  157,  162,  157,  162,  159,  165,
      163,  157,  169,  157,  563,  166,  164,  185,  171,  170,
      181,  181,  168,  182,  182,  167,  165,  162,  162,  162,
      162,  188,  163,  163,  172,  169,  183,  183,  162,  173,

      162,  174,  170,  163,  162,  186,  162,  557,  195,  163,
      188,  172,  194,  189,  175,  190,  173,  196,  197,  198,
      198,  214,  203,  202,  174,  176,  195,  177,  186,  194,
      157,  204,  157,  162,  190,  162,  221,  215,  200,  200,
      202,  203,  176,  217,  216,  214,  177,  223,  204,  162,
      157,  162,  157,  157,  222,  157,  218,  205,  205,  221,
      206,  215,  224,  207,  223,  208,  216,  217,  230,  209,
      230,  210,  211,  212,  225,  218,  213,  312,  222,  228,
      228,  229,  229,  313,  206,  224,  207,  231,  242,  242,
      210,  211,  230,  213,  230,  555,  230,  225,  230,  230,

      230,  230,  230,  230,  230,  230,  230,  230,  230,  230,
      230,  233,  230,  230,  230,  230,  230,  251,  230,  237,
      238,  232,  243,  243,  157,  234,  157,  239,  249,  235,
      245,  245,  291,  291,  233,  236,  254,  240,  232,  256,
      255,  251,  237,  238,  241,  249,  235,  246,  257,  246,
      239,  252,  247,  252,  254,  248,  248,  255,  258,  253,
      253,  241,  256,  260,  270,  262,  263,  157,  268,  157,
      273,  257,  269,  272,  283,  274,  259,  230,  554,  230,
      280,  281,  258,  270,  282,  277,  278,  260,  262,  263,
      284,  268,  274,  259,  273,  269,  272,  280,  283,  285,

      281,  282,  230,  230,  230,  230,  287,  288,  246,  288,
      246,  288,  284,  288,  295,  289,  289,  306,  285,  290,
      290,  292,  292,  246,  157,  246,  157,  307,  246,  287,
      246,  293,  294,  247,  252,  316,  252,  295,  252,  306,
      252,  547,  315,  310,  309,  311,  162,  317,  162,  297,
      307,  163,  298,  316,  299,  323,  546,  319,  300,  315,
      301,  302,  303,  309,  311,  304,  162,  162,  162,  162,
      317,  163,  163,  297,  321,  298,  326,  326,  323,  301,
      302,  319,  304,  327,  327,  230,  328,  230,  330,  230,
      333,  230,  334,  288,  345,  288,  336,  336,  321,  337,

      337,  335,  335,  328,  339,  339,  288,  346,  288,  340,
      340,  334,  330,  333,  336,  336,  343,  345,  347,  349,
      344,  351,  352,  353,  353,  353,  353,  353,  367,  353,
      346,  353,  375,  353,  343,  545,  348,  344,  353,  356,
      353,  369,  347,  349,  351,  352,  354,  353,  353,  353,
      353,  367,  355,  348,  353,  375,  353,  357,  353,  353,
      353,  353,  356,  360,  353,  369,  353,  358,  353,  355,
      353,  361,  398,  157,  362,  157,  162,  377,  162,  359,
      230,  163,  230,  372,  358,  372,  360,  288,  363,  288,
      398,  373,  373,  372,  361,  372,  364,  362,  382,  382,

      377,  374,  374,  380,  380,  381,  383,  157,  383,  157,
      157,  384,  157,  364,  385,  385,  383,  388,  383,  389,
      397,  384,  391,  394,  386,  386,  392,  402,  393,  395,
      404,  401,  403,  353,  405,  353,  353,  397,  353,  388,
      406,  391,  389,  408,  399,  399,  402,  393,  401,  403,
      353,  157,  353,  157,  404,  162,  405,  162,  451,  406,
      163,  372,  162,  372,  162,  416,  408,  163,  538,  411,
      411,  412,  412,  372,  230,  372,  230,  417,  417,  418,
      418,  412,  412,  383,  451,  383,  424,  424,  416,  383,
      383,  383,  383,  509,  425,  384,  425,  533,  424,  424,

      425,  425,  425,  425,  425,  419,  425,  425,  425,  425,
      425,  420,  425,  426,  425,  440,  421,  422,  462,  428,
      423,  425,  425,  425,  425,  433,  425,  429,  425,  427,
      420,  532,  440,  421,  422,  462,  430,  432,  442,  524,
      431,  434,  428,  425,  523,  425,  427,  425,  433,  425,
      437,  445,  437,  430,  353,  438,  353,  446,  439,  439,
      432,  353,  442,  353,  434,  395,  157,  435,  157,  447,
      447,  448,  450,  450,  445,  436,  446,  162,  372,  162,
      372,  230,  163,  230,  230,  230,  230,  230,  454,  456,
      458,  383,  436,  383,  466,  425,  384,  425,  464,  463,

      457,  465,  467,  459,  460,  425,  455,  425,  425,  469,
      425,  456,  454,  458,  521,  464,  466,  457,  463,  473,
      437,  467,  437,  455,  472,  465,  472,  475,  470,  471,
      482,  437,  469,  437,  483,  353,  438,  353,  478,  478,
      484,  230,  473,  230,  480,  480,  485,  486,  487,  482,
      475,  483,  488,  488,  489,  489,  425,  490,  425,  484,
      492,  496,  425,  485,  425,  495,  497,  497,  498,  505,
      486,  487,  506,  506,  490,  499,  499,  498,  507,  507,
      496,  472,  510,  472,  492,  353,  511,  353,  495,  500,
      501,  512,  505,  508,  508,  509,  513,  515,  516,  425,

      520,  425,  517,  522,  517,  510,  528,  528,  512,  511,
      518,  518,  514,  517,  515,  517,  353,  516,  353,  513,
      504,  519,  519,  520,  503,  525,  522,  525,  530,  530,
      526,  531,  531,  527,  527,  498,  525,  353,  525,  353,
      353,  526,  353,  536,  529,  529,  498,  534,  534,  535,
      535,  537,  539,  540,  541,  542,  517,  502,  517,  544,
      544,  425,  548,  425,  543,  543,  525,  536,  525,  494,
      540,  517,  353,  517,  353,  537,  539,  541,  542,  544,
      544,  525,  559,  525,  556,  548,  550,  550,  493,  549,
      549,  551,  551,  525,  558,  525,  552,  552,  526,  553,

      553,  550,  550,  525,  491,  525,  559,  556,  526,  560,
      481,  527,  527,  525,  517,  525,  517,  558,  526,  568,
      568,  529,  529,  561,  561,  562,  560,  425,  425,  425,
      425,  425,  570,  425,  564,  564,  565,  525,  566,  525,
      566,  571,  526,  573,  574,  574,  582,  425,  567,  425,
      575,  575,  566,  566,  566,  566,  570,  578,  578,  479,
      576,  577,  579,  579,  448,  571,  573,  583,  583,  477,
      582,  584,  584,  585,  585,  586,  586,  587,  587,  588,
      588,  592,  592,  593,  593,  594,  594,  595,  595,  596,
      596,  596,  596,  597,  597,  598,  598,  476,  313,  474,

      468,  461,  453,  452,  449,  444,  443,  441,  381,  415,
      414,  413,  410,  409,  407,  400,  396,  390,  387,  379,
      378,  192,  376,  371,  370,  368,  366,  365,  350,  342,
      341,  338,  332,  331,  329,  325,  324,  322,  320,  318,
      113,  314,  308,  305,  296,  286,  279,  276,  275,  271,
      267,  266,  265,  264,  261,  250,  244,  227,  226,  220,
      219,  201,  199,  153,  193,  187,  184,  179,  178,  150,
      138,  137,  136,  135,  134,  133,  132,  131,  130,  129,
      128,  127,  126,  125,  138,  137,  136,  135,  134,  133,
      132,  131,  130,  129,  128,  127,  126,  125,  124,  123,

      115,  108,  107,  104,   76,   88,   83,   76,   73,   68,
       52,  599,    3,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599
    } ;

static yyconst flex_int16_t yy_chk[1362] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    5,    9,
        5,   10,    5,    9,    5,    5,    6,    6,   11,    5,
        5,  584,    5,    7,    7,   15,    5,    9,   12,   11,
        9,  583,    5,    5,   10,    5,    5,    5,    5,    5,
        5,   11,    8,    5,    8,   13,   12,   18,   15,    8,
        8,    8,   12,   16,   17,   20,  582,   16,   13,   19,

       29,   21,   22,   12,  571,   17,   24,   29,   20,   13,
       18,   16,   25,   19,   21,   22,   17,   16,   27,   24,
       16,   44,   17,   30,   45,   25,   31,   33,   16,   34,
       30,   27,   36,   31,   33,   48,   34,   38,   38,   36,
       39,   39,   40,   44,   40,   41,   41,   45,   51,   49,
       55,   49,   56,   40,   48,   50,   40,   53,   40,   54,
      570,   50,   40,   57,   40,   40,   40,   51,   55,   40,
       49,   56,   58,   59,   53,  149,   54,   40,   94,   40,
       57,  149,   95,   40,   40,   42,   40,   42,   91,   91,
       91,   42,   42,   42,   42,   58,   59,   92,   92,   92,

       93,   94,   96,   97,   93,   95,   99,  100,  101,  101,
      101,  102,  102,  103,  103,  104,  564,  104,   93,  561,
       96,   93,  105,  106,  105,  106,   96,   97,  559,   99,
      100,  107,  553,  107,  104,  139,  139,   96,  106,  108,
      109,  108,  109,  110,  108,  110,  112,  111,  112,  111,
      113,  105,  113,  108,  116,  144,  116,  107,  114,  112,
      114,  106,  111,  114,  115,  117,  115,  117,  105,  109,
      117,  118,  114,  118,  548,  110,  108,  144,  116,  115,
      140,  140,  112,  141,  141,  111,  109,  119,  120,  119,
      120,  147,  119,  120,  117,  114,  142,  142,  121,  118,

      121,  119,  115,  121,  122,  145,  122,  539,  152,  122,
      147,  117,  151,  148,  120,  148,  118,  153,  153,  155,
      155,  164,  160,  159,  119,  121,  152,  122,  145,  151,
      157,  161,  157,  163,  148,  163,  173,  165,  157,  157,
      159,  160,  121,  169,  168,  164,  122,  175,  161,  162,
      166,  162,  166,  167,  174,  167,  170,  162,  162,  173,
      162,  165,  176,  162,  175,  162,  168,  169,  184,  162,
      184,  162,  162,  162,  177,  170,  162,  260,  174,  181,
      181,  183,  183,  260,  162,  176,  162,  184,  196,  196,
      162,  162,  185,  162,  185,  537,  186,  177,  186,  187,

      188,  187,  188,  189,  190,  189,  190,  191,  192,  191,
      192,  186,  193,  194,  193,  194,  195,  204,  195,  190,
      191,  185,  197,  197,  201,  187,  201,  193,  202,  188,
      199,  199,  244,  244,  186,  189,  206,  194,  185,  207,
      206,  204,  190,  191,  195,  202,  188,  200,  208,  200,
      193,  205,  200,  205,  206,  200,  200,  206,  209,  205,
      205,  195,  207,  210,  221,  212,  213,  216,  219,  216,
      224,  208,  220,  223,  235,  225,  209,  230,  536,  230,
      232,  233,  209,  221,  234,  230,  230,  210,  212,  213,
      238,  219,  225,  209,  224,  220,  223,  232,  235,  239,

      233,  234,  236,  237,  236,  237,  241,  242,  247,  242,
      247,  243,  238,  243,  250,  242,  242,  255,  239,  243,
      243,  245,  245,  246,  249,  246,  249,  256,  248,  241,
      248,  246,  246,  248,  253,  263,  253,  250,  252,  255,
      252,  522,  262,  259,  258,  259,  264,  267,  264,  252,
      256,  264,  252,  263,  252,  274,  521,  269,  252,  262,
      252,  252,  252,  258,  259,  252,  266,  271,  266,  271,
      267,  266,  271,  252,  272,  252,  277,  277,  274,  252,
      252,  269,  252,  278,  278,  279,  280,  279,  282,  284,
      286,  284,  287,  288,  298,  288,  289,  289,  272,  291,

      291,  288,  288,  280,  293,  293,  290,  299,  290,  294,
      294,  287,  282,  286,  290,  290,  297,  298,  300,  301,
      297,  303,  304,  306,  307,  306,  307,  305,  320,  305,
      299,  308,  329,  308,  297,  520,  300,  297,  309,  307,
      309,  323,  300,  301,  303,  304,  305,  310,  311,  310,
      311,  320,  306,  300,  313,  329,  313,  308,  312,  314,
      312,  314,  307,  311,  315,  323,  315,  309,  316,  306,
      316,  312,  352,  318,  314,  318,  322,  332,  322,  310,
      328,  322,  328,  326,  309,  326,  311,  336,  315,  336,
      352,  326,  326,  327,  312,  327,  316,  314,  338,  338,

      332,  327,  327,  335,  335,  335,  339,  341,  339,  341,
      342,  339,  342,  316,  339,  339,  340,  344,  340,  345,
      351,  340,  347,  349,  340,  340,  348,  356,  348,  349,
      358,  355,  357,  359,  361,  359,  353,  351,  353,  344,
      362,  347,  345,  364,  353,  353,  356,  348,  355,  357,
      360,  365,  360,  365,  358,  366,  361,  366,  418,  362,
      366,  372,  368,  372,  368,  379,  364,  368,  512,  372,
      372,  373,  373,  374,  378,  374,  378,  381,  381,  382,
      382,  374,  374,  384,  418,  384,  385,  385,  379,  383,
      386,  383,  386,  508,  387,  386,  387,  506,  386,  386,

      388,  390,  388,  390,  389,  383,  389,  391,  392,  391,
      392,  383,  394,  387,  394,  401,  383,  383,  427,  389,
      383,  395,  393,  395,  393,  394,  396,  390,  396,  388,
      383,  505,  401,  383,  383,  427,  391,  393,  403,  496,
      392,  396,  389,  397,  495,  397,  388,  398,  394,  398,
      399,  407,  399,  391,  400,  399,  400,  408,  399,  399,
      393,  405,  403,  405,  396,  493,  409,  397,  409,  411,
      411,  411,  417,  417,  407,  398,  408,  410,  412,  410,
      412,  413,  410,  413,  414,  415,  414,  415,  421,  422,
      423,  424,  398,  424,  433,  425,  424,  425,  429,  428,

      422,  430,  434,  425,  425,  431,  421,  431,  432,  436,
      432,  422,  421,  423,  492,  429,  433,  422,  428,  441,
      437,  434,  437,  421,  438,  430,  438,  444,  437,  437,
      453,  439,  436,  439,  454,  440,  439,  440,  448,  448,
      455,  449,  441,  449,  451,  451,  456,  457,  458,  453,
      444,  454,  459,  459,  460,  460,  461,  462,  461,  455,
      464,  469,  466,  456,  466,  468,  470,  470,  470,  477,
      457,  458,  478,  478,  462,  471,  471,  471,  479,  479,
      469,  472,  481,  472,  464,  476,  482,  476,  468,  472,
      472,  483,  477,  480,  480,  480,  484,  486,  487,  490,

      491,  490,  488,  494,  488,  481,  498,  498,  483,  482,
      488,  488,  485,  489,  486,  489,  502,  487,  502,  484,
      475,  489,  489,  491,  474,  497,  494,  497,  500,  500,
      497,  501,  501,  497,  497,  497,  499,  503,  499,  503,
      504,  499,  504,  510,  499,  499,  499,  507,  507,  509,
      509,  511,  513,  514,  515,  516,  517,  473,  517,  518,
      518,  523,  524,  523,  517,  517,  526,  510,  526,  467,
      514,  519,  532,  519,  532,  511,  513,  515,  516,  519,
      519,  525,  541,  525,  538,  524,  527,  527,  465,  525,
      525,  528,  528,  529,  540,  529,  533,  533,  529,  535,

      535,  529,  529,  530,  463,  530,  541,  538,  530,  542,
      452,  530,  530,  531,  544,  531,  544,  540,  531,  552,
      552,  531,  531,  543,  543,  543,  542,  545,  546,  545,
      546,  547,  556,  547,  549,  549,  549,  550,  551,  550,
      551,  558,  550,  560,  562,  562,  573,  563,  551,  563,
      565,  565,  566,  587,  566,  587,  556,  567,  567,  450,
      566,  566,  569,  569,  447,  558,  560,  574,  574,  446,
      573,  575,  575,  576,  576,  577,  577,  578,  578,  579,
      579,  585,  585,  586,  586,  590,  590,  591,  591,  592,
      592,  593,  593,  594,  594,  595,  595,  445,  443,  442,

      435,  426,  420,  419,  416,  406,  404,  402,  380,  377,
      376,  375,  369,  367,  363,  354,  350,  346,  343,  334,
      333,  331,  330,  325,  324,  321,  319,  317,  302,  296,
      295,  292,  285,  283,  281,  276,  275,  273,  270,  268,
      265,  261,  257,  254,  251,  240,  231,  227,  226,  222,
      218,  217,  215,  214,  211,  203,  198,  179,  178,  172,
      171,  158,  156,  154,  150,  146,  143,  124,  123,   98,
       90,   89,   88,   87,   86,   85,   84,   83,   82,   81,
       80,   79,   78,   77,   75,   74,   73,   72,   71,   70,
       69,   68,   67,   66,   65,   64,   63,   62,   61,   60,

       52,   47,   46,   43,   37,   35,   32,   28,   26,   23,
       14,    3,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "./dtimep.lex"
/*
** dtimep.lex exceeds the default table capacities for some old versions
** of lex (and the minimum defaults as specified by POSIX).  The following
** choices meet or exceed the lex defaults for older SunOS4.x, Solaris,
** HPUX, and AIX.
*/
#line 12 "./dtimep.lex"
#include <time.h>
#include <ctype.h>
#include <h/tws.h>

/*
** Since we're looking at a string at a time, don't worry about
** wrapping to the next buffer.
*/
#define yywrap() 1
#define YY_SKIP_YYWRAP

#define YY_NO_INPUT

/*
** This is the tricky thing that makes this function cool.  We
** replace the traditional int yylex(void) declaration with our
** dparsetime() declaration, essentially piggy-backing off the
** utility of the yylex() function and adding what we need to make
** the parsing function useful to us.
*/
#define YY_DECL struct tws *dparsetime(char *lexstr)

/*
** yyerminate() is called after the input string is matched to
** completion (actually, when the lexer reaches an EOF).  The only
** thing that really needs to be in this macro function is the
** return call, which must be substituted inline into dparsetime.
*/

#define yyterminate() (void)yy_delete_buffer(lexhandle); \
	if(!(tw.tw_flags & TW_SUCC)) { \
		return (struct tws *)NULL; \
	} \
	if(tw.tw_year < 1970) \
		tw.tw_year += 1900; \
	if(tw.tw_year < 1970) \
		tw.tw_year += 100; \
	return(&tw)

/*
** Patchable flag that says how to interpret NN/NN/NN dates. When
** true, we do it European style: DD/MM/YY. When false, we do it
** American style: MM/DD/YY.  Of course, these are all non-RFC822
** compliant.
*/
int europeandate = 0;

static int
name2num(char *name, char *names[])
{
	int i;

	for (i=0; names[i]; i++) {
		if (strncasecmp(name, names[i], strlen(names[i]))==0) {
			return i;
		}
	}
	return 0;
}

/*
** The SET* macros will parse for the appropriate field, and leave the
** cp pointer at the first character after the desired field. Be
** careful with variable-length fields or alpha-num mixes.
**
** The SKIP* macros skip over characters of a particular class and
** leave cp at the position of the first character that doesn't match
** that class. Correspondingly, SKIPTO* skips until it reaches a
** character of a particular class.
*/

#define INIT() { cp = yytext;}
#define SETWDAY()  { tw.tw_wday = name2num(cp, tw_dotw); \
	tw.tw_flags &= ~TW_SDAY; tw.tw_flags |= TW_SEXP; SKIPA(); }
#define SETMON()  { tw.tw_mon = name2num(cp, tw_moty); SKIPA(); }
#define SETMON_NUM()  { tw.tw_mon = atoi(cp)-1; SKIPD(); }
#define SETYEAR()  { tw.tw_year = atoi(cp); SKIPD(); }
#define SETDAY()  { tw.tw_mday = atoi(cp); tw.tw_flags |= TW_YES; SKIPD(); }
#define SETTIME()  { tw.tw_hour = atoi(cp); cp += 2; SKIPTOD(); \
	tw.tw_min = atoi(cp); cp += 2; if(*cp == ':') { \
	tw.tw_sec = atoi(++cp); SKIPD(); } }
#define SETZONE(x)  { tw.tw_zone = ((x)/100)*60+(x)%100; \
	tw.tw_flags |= TW_SZEXP; SKIPD(); }
#define SETZONEC(h, m)  { tw.tw_zone = (h)*60+(m); \
	tw.tw_flags |= TW_SZEXP; SKIPD(); }
#define SETDST()  { tw.tw_flags |= TW_DST; }
#define SKIPD()  { while ( isdigit(*cp++) ) ; --cp; }
#define SKIPTOD()  { while ( !isdigit(*cp++) ) ; --cp; }
#define SKIPA()  { while ( isalpha(*cp++) ) ; --cp; }
#define SKIPTOA()  { while ( !isalpha(*cp++) ) ; --cp; }
#define SKIPSP()  { while ( isspace(*cp++) ) ; --cp; }
#define SKIPTOSP()  { while ( !isspace(*cp++) ) ; --cp; }

#ifdef ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST
# ifdef HAVE_SYS_TIME_H
#  include <sys/time.h>
# endif
#include <time.h>

static void
zonehack (struct tws *tw)
{
	struct tm *tm;

	if (dmktime (tw) == (time_t) -1)
		return;

	tm = localtime (&tw->tw_clock);
	if (tm->tm_isdst) {
		tw->tw_flags |= TW_DST;
		tw->tw_zone -= 60;
	}
}
#endif /* ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST */
/*
** The year can either be 2 digits, or 4. However, after
** Y2K, we found that some MUA were reporting the year 100, hence
** the middle term here. yyterminate() resolves the actual
** issues with 2-digit years.
*/
#line 1074 "<stdout>"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * _in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * _out_str  );

			int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput (int c,char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{
#line 170 "./dtimep.lex"


	/*
	** This section begins the definition of dparsetime().
	** Put here any local variable definitions and initializations
	*/
	YY_BUFFER_STATE lexhandle;

	unsigned char *cp;
	static struct tws tw;

	memset(&tw,0,sizeof(struct tws));

	lexhandle = yy_scan_string(lexstr);


#line 1309 "<stdout>"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 600 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1313 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 186 "./dtimep.lex"
{
	INIT();
	SETWDAY();
	SKIPTOA();
	SETMON();
	SKIPTOD();
	SETDAY();
	SKIPTOD();
	SETTIME();
	SKIPTOD();
	SETYEAR();
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 199 "./dtimep.lex"
{
	INIT();
	SETWDAY();
	SKIPTOD();
	SETDAY();
	SKIPTOA();
	SETMON();
	SKIPTOD();
	SETYEAR();
	SKIPTOD();
	SETTIME();
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 211 "./dtimep.lex"
{
	INIT();
	SETDAY();
	SKIPTOA();
	SETMON();
	SKIPTOD();
	SETYEAR();
	SKIPTOD();
	SETTIME();
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 221 "./dtimep.lex"
{
	INIT();
	SETWDAY();
	SKIPTOA();
	SETMON();
	SKIPTOD();
	SETDAY();
	SKIPTOD();
	SETYEAR();
	SKIPTOD();
	SETTIME();
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 233 "./dtimep.lex"
{
	INIT();
	SETWDAY();
	SKIPTOA();
	SETMON();
	SKIPTOD();
	SETDAY();
	SKIPTOD();
	SETYEAR();
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 243 "./dtimep.lex"
{
	INIT();
	SETMON();
	SKIPTOD();
	SETDAY();
	SKIPTOD();
	SETYEAR();
	SKIPTOA();
	SETWDAY();
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 253 "./dtimep.lex"
{
	INIT();
	SETMON();
	SKIPTOD();
	SETDAY();
	SKIPTOD();
	SETYEAR();
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 261 "./dtimep.lex"
{
	INIT();
	SETYEAR();
	SKIPTOD();
	SETMON_NUM();
	SKIPTOD();
	SETDAY();
	SKIPTOD();
	SETTIME();
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 271 "./dtimep.lex"
{
	INIT();
	SETYEAR();
	SKIPTOD();
	SETMON_NUM();
	SKIPTOD();
	SETDAY();
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 279 "./dtimep.lex"
{
	fprintf(stderr, "the highly ambiguous date format XX-XX-XX..."
			" is no longer supported\n");
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 283 "./dtimep.lex"
{
	INIT();
	if(europeandate) {
		/* DD/MM/YY */
		SETDAY();
		SKIPTOD();
		SETMON_NUM();
	} else {
		/* MM/DD/YY */
		SETMON_NUM();
		SKIPTOD();
		SETDAY();
	}
	SKIPTOD();
	SETYEAR();
	SKIPTOD();
	SETTIME();
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 301 "./dtimep.lex"
{
	INIT();
	if(europeandate) {
		/* DD/MM/YY */
		SETDAY();
		SKIPTOD();
		SETMON_NUM();
	} else {
		/* MM/DD/YY */
		SETMON_NUM();
		SKIPTOD();
		SETDAY();
	}
	SKIPTOD();
	SETYEAR();
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 318 "./dtimep.lex"

	YY_BREAK
case 14:
YY_RULE_SETUP
#line 319 "./dtimep.lex"
tw.tw_hour += 12;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 321 "./dtimep.lex"
{
	INIT();
	SKIPTOD();
	SETZONE(atoi(cp));
#ifdef ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST
	zonehack (&tw);
#endif /* ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST */
	yyterminate();
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 330 "./dtimep.lex"
{
	INIT();
	SKIPTOD();
	SETZONE(-atoi(cp));
#ifdef ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST
	zonehack (&tw);
#endif /* ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST */
	yyterminate();

}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 340 "./dtimep.lex"
{
	INIT();
	SKIPTOD();
	SETZONEC(atoi(cp), atoi(cp+3));
#ifdef ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST
	zonehack (&tw);
#endif /* ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST */
	yyterminate();
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 349 "./dtimep.lex"
{
	INIT();
	SKIPTOD();
	SETZONEC(-atoi(cp), -atoi(cp+3));
#ifdef ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST
	zonehack (&tw);
#endif /* ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST */
	yyterminate();

}
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 359 "./dtimep.lex"
INIT(); SETZONE(0); yyterminate();
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 360 "./dtimep.lex"
INIT(); SETZONE(0); yyterminate();
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 361 "./dtimep.lex"
INIT(); SETZONE(-500); yyterminate();
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 362 "./dtimep.lex"
{ INIT(); SETDST(); SETZONE(-500); yyterminate(); }
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 363 "./dtimep.lex"
INIT(); SETZONE(-600); yyterminate();
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 364 "./dtimep.lex"
{ INIT(); SETDST(); SETZONE(-600); yyterminate(); }
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 365 "./dtimep.lex"
INIT(); SETZONE(-700); yyterminate();
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 366 "./dtimep.lex"
{ INIT(); SETDST(); SETZONE(-700); yyterminate(); }
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 367 "./dtimep.lex"
INIT(); SETZONE(-800); yyterminate();
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 368 "./dtimep.lex"
{ INIT(); SETDST(); SETZONE(-800); yyterminate(); }
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 369 "./dtimep.lex"
INIT(); SETZONE(-330); yyterminate();
	YY_BREAK
case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 370 "./dtimep.lex"
INIT(); SETZONE(-400); yyterminate();
	YY_BREAK
case 31:
/* rule 31 can match eol */
YY_RULE_SETUP
#line 371 "./dtimep.lex"
{ INIT(); SETDST(); SETZONE(-400); yyterminate(); }
	YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
#line 372 "./dtimep.lex"
INIT(); SETZONE(-1000); yyterminate();
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 373 "./dtimep.lex"
{ INIT(); SETDST(); SETZONE(-1000); yyterminate(); }
	YY_BREAK
case 34:
/* rule 34 can match eol */
YY_RULE_SETUP
#line 374 "./dtimep.lex"

	YY_BREAK
case 35:
YY_RULE_SETUP
#line 376 "./dtimep.lex"
ECHO;
	YY_BREAK
#line 1709 "<stdout>"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 600 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 600 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
	yy_is_jam = (yy_current_state == 599);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,(int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 376 "./dtimep.lex"


/*
** This is a portable way to squash a warning about the yyunput()
** function being static but never used. It costs us a tiny amount
** of extra code in the binary but the other options are:
** "%option nounput" which is flex-specific
** makefile hackery just to compile dtimep.c with different flags
*/
void dtimep_yyunput(int c)
{
	unput(c);
}

